Contributors
==============

``hepfile`` is openly developed and benefits from the contributions and feedback
from its users.
The ``hepfile`` dev team would like to thank all contributors to the project for
their support and help.
Thank you!

Contributors include:

- Matt Bellis
- Matt Dreyer
- Willow Hagen
- Ryan Mikulec
